@@ -17,15 +17,15 @@ def _yieldPosts(name, soup):
 		except:
 			...
 
-def _getPostsSoup(name, post_id=None):
+def _getPostsSoup(name, post_id, direction):
 	link = 'https://t.me/s/' + name
 	if post_id:
-		link += '/' + str(post_id)
-
+		link += '?%s=%d' % (direction, post_id)
 	return getSoup(link, force_cache=post_id)
 
-def getPosts(name, post_id=None):
-	soup = _getPostsSoup(name, post_id = post_id)
+def getPosts(name, post_id=None, direction='after'):
+	soup = _getPostsSoup(name, post_id = post_id, 
+		direction = direction)
 	return list(_yieldPosts(name, soup))
 
 def getPost(name, post_id):
